Top

    Origins Thursday
    Columbus, Ohio
    July 4th 2002
    25 players
    Jay Kristoff

    I just got home from an amazing first day at Origins. I was able to
    eak out a tournament victory with my Mirembe Rides Again deck. 25
    meths played in this event. 4 of the 5 finalists were from Ohio, the
    other was Halcyan2 who is from somewhere in Illinois.
    I'm sure details on this and the other events will follow. It's
    bed time for me, so here is the deck:

    Mirembe Rides Again!
    by Jay Kristoff - jck@columbus.rr.com

    Crypt (12 cards, min=16, max=20, avg=4.67)
    ------------------------------------------
    6x Mirembe Kabbada	5   PRO SER ani	 Gangrel:2
    2x Camille Devereux	5   FOR PRO ani	 Gangrel:1
    2x Raven		5   FOR PRO ani	 Gangrel:1
    2x Chandler Hungerford	3   PRO		 Gangrel:2

    Library 90
    Masters 14
    1x Zoo Hunting Grounds
    2x Ecoterrorists
    1x Powerbase Montreal
    1x Club Zombie
    1x London Evening Star
    1x KRCG News Radio
    1x Rumor Mill
    1x Backways
    2x Smiling Jack the Anarch
    1x Barrens
    1x Direct Intervention
    1x Sudden Reversal

    Minion 76
    22x Earth Meld
    12x Forced Awakening
    6x Form of Mist
    6x Quick Meld
    4x Earth Control
    3x Form of Corruption
    3x Atonement
    3x Raven Spy
    2x Mr. Winthrop
    2x Renegade Garou
    2x Army of Rats
    2x Shadow of the Beast
    2x Temptation
    2x Arson
    2x Ecstasy
    1x Set's Call
    1x Tasha Morgan
    1x J.S. Simmons Esq.